pub struct VenueOrderIdOwnershipError {
pub venue_order_id: VenueOrderId,
pub existing_client_order_id: ClientOrderId,
pub claimant_client_order_id: ClientOrderId,
}Expand description
Error returned when a venue order ID is already owned by another client order.
Fields
venue_order_id: VenueOrderIdThe venue order ID whose ownership conflicts.
existing_client_order_id: ClientOrderIdThe client order which already owns the venue order ID.
claimant_client_order_id: ClientOrderIdThe client order attempting to claim the venue order ID.